@@ -157,6 +157,10 @@ def run(runner, job, docker):
     logmsg.FATAL_EXIT = False
 
     trace.writeline("Running on {} {} {}".format(gethostname(), NAME, VERSION))
+    if docker:
+        trace.writeline("Using Docker executor")
+    else:
+        trace.writeline("Using shell executor")
 
     tempdir = tempfile.mkdtemp(dir=runner.builds)
     build_dir = os.path.join(tempdir, get_variable(job, "CI_PROJECT_PATH"))
@@ -190,7 +194,7 @@ def run(runner, job, docker):
         emulator_job = configloader.load_job(config, jobname)
         trace.emulator_job = emulator_job
 
-        runner.get_dependencies(trace, job, emulator_job.dependencies)
+        runner.get_dependencies(trace, job, build_dir_abs)
 
         emulator_job.stdout = trace
 
