@@ -12,7 +12,7 @@ import sys
 import time
 import yaml
 from requests.exceptions import ConnectionError, HTTPError
-from GitlabPyRunner import consts, runner, executor
+from GitlabPyRunner import consts, runner, executor, common
 from gitlabemu import logmsg
 
 
@@ -43,15 +43,19 @@ parser.add_argument("--start", type=str,
                     help="Start the runner defined in the config file"
                     )
 
+parser.add_argument("--once", action="store_true", default=False,
+                    help="Run only one job and then exit"
+                    )
+
 if __name__ == "__main__":
     opts = parser.parse_args()
 
     if opts.register:
         if not opts.desc:
-            opts.desc = consts.NAME + " on " + socket.gethostname()
+            opts.desc = consts.NAME + " on " + common.gethostname()
 
         if not opts.tag:
-            opts.tag = ["new-python-runner-" + socket.gethostname()]
+            opts.tag = ["new-python-runner-" + common.gethostname()]
 
         if not opts.regtoken:
             raise RuntimeError("missing required --regtoken")
@@ -98,30 +102,44 @@ if __name__ == "__main__":
         os.chdir(config["dir"])
         extype = config["executor"]
 
+        if opts.once:
+            logmsg.info("Will exit after one job")
+
+        exitstatus = 1
+
+        docker = False
+
         # loop forever to cope with some common errors that can come up
-        while True:
+        while not opts.once:
             if extype == "shell":
                 run = runner.Runner(config["server"], config["token"])
             elif extype == "docker":
+                docker = True
                 run = runner.DockerRunner(config["server"], config["token"])
             else:
                 raise RuntimeError("unsupported executor type '{}'".format(extype))
 
             try:
                 run.shell = config["shell"]
-                while True:
+                while not opts.once:
                     interval = 40
                     logmsg.info("Polling for jobs.. ({} sec)".format(interval))
                     job = run.poll()
                     if not job:
                         time.sleep(interval)
                     else:
-                        result = executor.run(run, job)
+                        result = executor.run(run, job, docker)
+                        exitstatus = result
+                        logmsg.info("Job {} has ended success={}".format(job["id"], result))
                         if result:
                             run.success(job)
                         else:
                             run.failed(job)
+
             except (ConnectionError, HTTPError) as err:
                 logmsg.warning("comms exception {}".format(err))
                 logmsg.warning("sleeping..")
                 time.sleep(90)
+
+        if exitstatus and opts.once:
+            sys.exit(exitstatus)
